@@ -133,6 +133,12 @@ QGeoSatelliteInfo &QGeoSatelliteInfo::operator=(const QGeoSatelliteInfo & other)
     the same as those of \a rhs. Otherwise returns \c false.
 */
 
+/*!
+    \fn void QGeoSatelliteInfo::swap(QGeoSatelliteInfo &other)
+    \since 6.2
+    \memberswap{satellite information}
+*/
+
 /*!
     Sets the Satellite System (GPS, GLONASS, ...) to \a system.
 */
@@ -142,6 +148,11 @@ void QGeoSatelliteInfo::setSatelliteSystem(SatelliteSystem system)
     d->system = system;
 }
 
+/*!
+    \property QGeoSatelliteInfo::satelliteSystem
+    \brief the satellite system in use, such as GPS or GLONASS.
+*/
+
 /*!
     Returns the Satellite System (GPS, GLONASS, ...)
 
@@ -176,7 +187,8 @@ void QGeoSatelliteInfo::setSatelliteIdentifier(int satId)
 }
 
 /*!
-    Returns the satellite identifier number.
+    \property QGeoSatelliteInfo::satelliteIdentifier
+    \brief the satellite identifier number.
 
     The satellite identifier number can be used to identify a satellite within
     the satellite system.
@@ -198,6 +210,10 @@ void QGeoSatelliteInfo::setSatelliteIdentifier(int satId)
     identifier ranges for different satellite systems may intersect. To uniquely
     identify a satellite, a combination of satelliteIndetifier() and
     \l satelliteSystem() must be used.
+*/
+
+/*!
+    Returns the satellite identifier number.
 
     \sa satelliteSystem()
 */
@@ -215,6 +231,11 @@ void QGeoSatelliteInfo::setSignalStrength(int signalStrength)
     d->signal = signalStrength;
 }
 
+/*!
+    \property QGeoSatelliteInfo::signalStrength
+    \brief the signal strength.
+*/
+
 /*!
     Returns the signal strength, or -1 if the value has not been set.
 */
@@ -229,7 +250,7 @@ int QGeoSatelliteInfo::signalStrength() const
 void QGeoSatelliteInfo::setAttribute(Attribute attribute, qreal value)
 {
     d.detach();
-    d->doubleAttribs[int(attribute)] = value;
+    d->doubleAttribs[attribute] = value;
 }
 
 /*!
@@ -241,9 +262,7 @@ void QGeoSatelliteInfo::setAttribute(Attribute attribute, qreal value)
 */
 qreal QGeoSatelliteInfo::attribute(Attribute attribute) const
 {
-    if (d->doubleAttribs.contains(int(attribute)))
-        return d->doubleAttribs[int(attribute)];
-    return -1;
+    return d->doubleAttribs.value(attribute, -1);
 }
 
 /*!
@@ -251,8 +270,11 @@ qreal QGeoSatelliteInfo::attribute(Attribute attribute) const
 */
 void QGeoSatelliteInfo::removeAttribute(Attribute attribute)
 {
-    d.detach();
-    d->doubleAttribs.remove(int(attribute));
+    const auto it = d->doubleAttribs.constFind(attribute);
+    if (it != d->doubleAttribs.cend()) {
+        d.detach();
+        d->doubleAttribs.erase(it);
+    }
 }
 
 /*!
@@ -260,7 +282,7 @@ void QGeoSatelliteInfo::removeAttribute(Attribute attribute)
 */
 bool QGeoSatelliteInfo::hasAttribute(Attribute attribute) const
 {
-    return d->doubleAttribs.contains(int(attribute));
+    return d->doubleAttribs.contains(attribute);
 }
 
 /*!
@@ -288,8 +310,8 @@ QDebug QGeoSatelliteInfo::debugStreaming(QDebug dbg, const QGeoSatelliteInfo &in
     dbg << ", signal-strength=" << info.d->signal;
 
 
-    QList<int> attribs = info.d->doubleAttribs.keys();
-    for (int i = 0; i < attribs.size(); ++i) {
+    const QList<QGeoSatelliteInfo::Attribute> attribs = info.d->doubleAttribs.keys();
+    for (qsizetype i = 0; i < attribs.size(); ++i) {
         dbg << ", ";
         switch (attribs[i]) {
             case QGeoSatelliteInfo::Elevation:
